@@ -21,7 +21,7 @@
 
 */
 
-#include <config.h>
+#include "config.h"
 
 #ifdef HAVE_GCRYPT_H
 
