@@ -22,7 +22,7 @@
 
 */
 
-#include <config.h>
+#include "config.h"
 #include <string.h>
 
 #include "internals.h"
