@@ -21,7 +21,7 @@
 
 */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 
@@ -249,11 +249,11 @@ int main(void)
 "struct _GArray {\n"
 "  /* Public */\n"
 "  gchar *data;\n"
-"  size_t len;\n"
+"  guint len;\n"
 "\n"
 "  /* Private */\n"
 "  guint element_size;\n"
-"  size_t allocated;\n"
+"  guint allocated;\n"
 "};\n"
 "\n"
 "WIN32_DLL GArray* g_array_new( gboolean zero_terminated, gboolean clear,\n"
