@@ -21,7 +21,7 @@
 
 */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 #include <string.h>
@@ -903,6 +903,7 @@ libspectrum_tape_raw_data_next_bit( libspectrum_tape_raw_data_block *block,
 
   if( state->bytes_through_block == block->length ) {
     state->state = LIBSPECTRUM_TAPE_STATE_PAUSE;
+    state->last_bit ^= 0x80;
     return;
   }
 
@@ -910,14 +911,12 @@ libspectrum_tape_raw_data_next_bit( libspectrum_tape_raw_data_block *block,
 
   /* Step through the data until we find an edge */
   do {
+    size_t bits_in_byte = (state->bytes_through_block == block->length - 1) ?
+        block->bits_in_last_byte : 8;
     length++;
-    if( ++(state->bits_through_byte) == 8 ) {
-      if( ++(state->bytes_through_block) == block->length - 1 ) {
-	state->bits_through_byte = 8 - block->bits_in_last_byte;
-      } else {
-	state->bits_through_byte = 0;
-      }
-      if( state->bytes_through_block == block->length )
+    if( ++(state->bits_through_byte) == bits_in_byte ) {
+      state->bits_through_byte = 0;
+      if( ++(state->bytes_through_block) == block->length )
 	break;
     }
   } while( ( block->data[state->bytes_through_block] <<
