@@ -21,7 +21,7 @@
 
 */
 
-#include <config.h>
+#include "config.h"
 
 #include <math.h>
 #include <stddef.h>
@@ -688,8 +688,9 @@ tzx_read_pause( libspectrum_tape *tape, const libspectrum_byte **ptr,
 
   /* Get the pause length */
   libspectrum_set_pause_ms( block, (*ptr)[0] + (*ptr)[1] * 0x100 );
-  /* TZX format spec says pause is low */
-  libspectrum_tape_block_set_level( block, 0 );
+  /* Pause blocks should change the pulse level to ensure that the
+   * last edge is properly finished, so set the block level to -1 */
+  libspectrum_tape_block_set_level( block, -1 );
   (*ptr) += 2;
 
   libspectrum_tape_append_block( tape, block );
