@@ -21,7 +21,7 @@
 
 */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -1206,6 +1206,10 @@ libspectrum_z80_write2( libspectrum_buffer *buffer, int *out_flags,
   if( libspectrum_snap_zxmmc_active( snap ) )
     *out_flags |= LIBSPECTRUM_FLAG_SNAPSHOT_MAJOR_INFO_LOSS;
 
+  /* .z80 format doesn't save the TTX2000S state at all */
+  if( libspectrum_snap_ttx2000s_active( snap ) )
+    *out_flags |= LIBSPECTRUM_FLAG_SNAPSHOT_MAJOR_INFO_LOSS;
+
   error = write_header( buffer, out_flags, snap );
   if( error != LIBSPECTRUM_ERROR_NONE ) return error;
 
